@@ -1,20 +1,16 @@
 from django.contrib import admin
-from .models import Activity
-from .models import Actor
+
+from .models import Actor, ActorCategory
 from .models import OldDevice
-from .models import ActivityInstall, ActivityRemove, ActivityReason
-from .models import ActorCategory
-
-
+from .models import Activity, ActivityInstall, ActivityRemove, ActivityReason
 
 @admin.register(ActorCategory)
 class ActorCategoryAdmin(admin.ModelAdmin):
     list_display = ['id', 'name']
 
-
-@admin.register(Activity)
-class ActivityAdmin(admin.ModelAdmin):
-    list_display = ['id', 'description', 'type']
+@admin.register(Actor)
+class ActorAdmin(admin.ModelAdmin):
+    list_display = ('id','name')
 
 
 @admin.register(OldDevice)
@@ -22,10 +18,9 @@ class OldDevice(admin.ModelAdmin):
     list_display = ['id']
 
 
-@admin.register(Actor)
-class ActorAdmin(admin.ModelAdmin):
-   list_display = ('id','name')
-
+@admin.register(Activity)
+class ActivityAdmin(admin.ModelAdmin):
+    list_display = ['id', 'description', 'type']
 
 @admin.register(ActivityInstall)
 class ActivityInstallAdmin(admin.ModelAdmin):
@@ -39,10 +34,10 @@ class ActivityRemoveAdmin(admin.ModelAdmin):
 class ActivityReason(admin.ModelAdmin):
     list_display = ['name', 'type']
 
- 
+
 #admin.site.register(Categoria)
 #admin.site.register(Registroo)
 
 #admin.site.register()
 
-# Register your models here.
\ No newline at end of file
+# Register your models here.
