@@ -310,7 +310,7 @@ class ActivityListView(LoginRequiredMixin, View):
         year_month_researched = None
         year_researched = None
 
-        first_activity = Activity.objects.all().order_by('when')[0]
+        first_activity = Activity.objects.all().order_by('when').first()
 
         if 'btn-search-research' in r:
             if r.get('search') is not None:
